Afrikaans
Akan
Albanian
Amharic
Arabic
Armenian
Azerbaijani
Basque
Belarusian
Bemba
Bengali
Bihari
Bosnian
Breton
Bulgarian
Cambodian
Catalan
Cebuano
Cherokee
Chichewa
Chinese (Simplified)
Chinese (Traditional)
Corsican
Croatian
Czech
Danish
Dutch
English
Esperanto
Estonian
Ewe
Faroese
Filipino
Finnish
French
Frisian
Ga
Galician
Georgian
German
Greek
Guarani
Gujarati
Haitian Creole
Hausa
Hawaiian
Hebrew
Hindi
Hmong
Hungarian
Icelandic
Igbo
Indonesian
Interlingua
Irish
Italian
Japanese
Javanese
Kannada
Kazakh
Kinyarwanda
Kirundi
Kongo
Korean
Krio (Sierra Leone)
Kurdish
Kurdish (Soranรฎ)
Kyrgyz
Laothian
Latin
Latvian
Lingala
Lithuanian
Lozi
Luganda
Luo
Luxembourgish
Macedonian
Malagasy
Malay
Malayalam
Maltese
Maori
Marathi
Mauritian Creole
Moldavian
Mongolian
Myanmar (Burmese)
Montenegrin
Nepali
Nigerian Pidgin
Northern Sotho
Norwegian
Norwegian (Nynorsk)
Occitan
Oriya
Oromo
Pashto
Persian
Polish
Portuguese (Brazil)
Portuguese (Portugal)
Punjabi
Quechua
Romanian
Romansh
Runyakitara
Russian
Samoan
Scots Gaelic
Serbian
Serbo-Croatian
Sesotho
Setswana
Seychellois Creole
Shona
Sindhi
Sinhalese
Slovak
Slovenian
Somali
Spanish
Sundanese
Swahili
Swedish
Tajik
Tamil
Tatar
Telugu
Thai
Tigrinya
Tonga
Tshiluba
Tumbuka
Turkish
Turkmen
Twi
Uighur
Ukrainian
Urdu
Uzbek
Vietnamese
Welsh
Wolof
Xhosa
Yiddish
Yoruba
Zulu
***
ANDY COHEN: Coming up on the 3-part "Valley" Reunion...
Thank you.
-Ready for this? Nervous? -I'm everything.
Bye, guys.
-Love you. -Smells like burnt hair in here.
[cellphone rings]
Hello? No, I'm at the "Valley" Reunion.
-It's gonna be great. -What's up, Andy?
-Hey, Luke. -How you doing?
I think I'm gonna lose a nipple today.
No one told me when mine was out.
Wow, you already have makeup on.
I know.
No.
[villainous music plays]
-You all right? -I'm ready to go to war.
Ugh! I'm a nervous wreck.
Oh, I'm hopefully gonna be seated in the back so that
nobody talks to me. [laughs] -No, you're not.
See how it's falling? I want that.
Yeah, yeah, yeah.
Let's get into it. It's gonna be a long fucking day.
ANDY: Jax, are you and Brittany gonna get a prenup?
JAX: No.
-No. -No? Why not?
[voice echoing] Because I'm gonna be with her forever.
ANDY: [voice echoing] Is she gonna be with you forever?
[voice echoing] Yes.
I will not touch that dirty dick with a 10-inch pole.
It's not what you said four months ago.
You knew we were filming whenever you did these things.
I'm not gonna play a role. I'm not an actor.
You degraded me constantly.
You made me literally lose my sparkle.
[under breath] God, with the fucking sparkle.
***
I want to be in love with you, but I don't know if I can.
She went this way, and I'm trying to make my way to her,
and she's going further that way.
Come on. A married woman with a child
asking a single guy for advice about her husband?
-That's wildly inappropriate. -Wildly inappropriate?
You told our client that you wanted to eat her out.
Get that sale.
Janet, you have transformed yourself. How'd you do that?
-Adderall and Pilates. -[laughter]
I want to know about the gay guy that was Zelle-ing Jesse money.
-I can tell you all about him. -Were you, like,
blowing him for money? -Don't look at me.
Who on this stage is still in the boys chat?
You are a clown, dude. You're a total clown.
-Are you kidding me? -You were, like, snake liar.
If they have that footage, they should show it.
-They will. -Crazy.
You're, like, kind of the Stassi Schroeder,
and you're kind of the Lala Kent,
and you're kind of the Scheana. -Are you doing this right now?
This man put me down, body-shamed me,
Believe it or not, I know some people think I'm not human.
I'm the devil.
Are you still in love with Brittany?
[dramatic music playing]
Are you still in love with Jax?
Hey, everybody. Welcome to "The Valley" Season 2 Reunion.
I'm Andy Cohen, reuniting for the first time
with the stars of everyone's favorite SoCal soap opera.
Wow. This is gonna be fun. Uh, Brittany, great to see you.
You, too.
Will tonight be the longest time
that you've spent with Jax in the last year?
-Yes. -Wow.
Jax, how does it feel to be wearing clothes
that aren't merch from your bar?
-[laughs] Uh, good. -[laughter]
ANDY: Is that a conscious decision on your part?
You know, you gotta support the bar.
Okay. Michelle, I heard
you moved in with your boyfriend Aaron.
-How's it going? -MICHELLE: Amazing.
-Good. -We have Isabella
50% of the time, and she really is happy.
Excellent.
That's not true.
-ANDY: Uh, hey, Jesse. -Hi.
We saw you in your tighty whities this season.
I've since ordered new underwear.
Zack told me they were a little too baggy.
-Droopy drawers. -What's going on?
So, yeah, I went a little more high cut brief now--
-Calvins, obviously. -Okay. Very good.
-Hi, Kristen. -KRISTEN: Hi.
-You look so beautiful pregnant. -Thank you. Thank you.
-How far along are you? -33 weeks and three days.
-Wow. -Don't stress me out.
My water could break. No, I'm just kidding.
-Okay. -[laughter]
How are you feeling about being here, Luke?
Uh, good. Actually, I'm feeling a little unprepared
because we don't have a go bag for the hospital with us.
-No, we don't. -[laughter]
ANDY: Nia, you and Danny went for it.
-[laughter] -We went for it. Number four.
Baby number four will be here soon.
-NIA: Yes. -How far along are you?
-I'm almost 34 weeks. Yeah. -Congratulations.
-Wow. -Danny, how many times
are we gonna hear you say, "Four under four"?
-Four under four. -[sighs heavily]
-Quite a bit. Quite a bit. -Yeah.
Zack, how did Benji enjoy your Scrotox?
Um, I thought he would have noticed it more.
-Yeah. -But apparently he didn't.
-[laughter] -Okay. Hi, Jasmine.
-Hi. -You're engaged.
-Yes. -Congratulations.
-Thank you. -Yay.
-[applause] -When is the big date?
-Uh, next summer. -Love a long engagement.
-Hi, Janet. -Hi.
You have transformed yourself.
-Lost a lot of baby weight. -How'd you do that?
-Adderall and Pilates. -[laughter]
JASMINE: That's real.
-Hey, Jason. -Hey, Andy.
You wearing your wedding ring today?
I'm wearing my wedding ring on me, yes.
Excellent. I wanna dive in.
Uh, you know, Kristen, you have called yourself an empath.
I have to say, you may have been the voice of reason this season.
-Who would have thunk? Growth. -Not me.
-Growth. -[laughter]
That's our favorite word right now.
-It is. -[laughter]
It feels like Crazy Kristen might truly be retired,
-She's a mom now. -That vir--you know.
-Yes. -There's still, like, some,
but it's like a different kind of crazy.
-[laughter] -How does that feel?
I had one moment that I was not proud of.
-Okay. -So if I can just
start this off with an apology to Janet
for just the crap that was flying out of my mouth
about, like, "beat your ass" or "knock you out."
I've never been so mad.
Don't make me knock your ass out.
-Like, seriously, don't. -Knock me out, Kristen.
-Knock me out. -You're a fucking fan, bitch.
I would never, ever, and that was
just so not my best moment, and also calling you a whore
because that's just obviously not true.
Um, but the decibels of my voice,
that high-pitched screaming--
I looked at Luke right after we watched it,
and I said, "Was that crazy?"
-And he goes, "Yeah, kinda." -ANDY: Right.
I was like, "Thank you for your honesty."
-Okay, note to self. So... -Okay.
-I appreciate the apology. -That's a good way to start.
Well, I wonder, you know, Jax and Brittany, um,
what is the status of your divorce?
Hopefully it's happening soon.
He called me the other day and said that he didn't know
if he was gonna get kicked off the show,
so he was prolonging it in case
he needed to get alimony from me.
Hmm.
-[exhales deeply] -That's...somewhat true.
-Brittany doesn't lie. -What did you say then?
Okay. I was prolonging it because of the podcast feed.
-That's what-- -That's not what you said.
Let's start this off with truth.
-I am telling the truth. -Jax.
-She doesn't lie. -JAX: I'm--I'm not--
That is verbatim what you said to me.
-What? -Don't act like
you didn't say that to me.
Then we'll agree with you, what you said.
See?
KRISTEN: All righty.
-[sighs] -Um...Jesse and Michelle,
what are your goals for tonight? Anything?
I know.
Well, you know, I think there was this, you know,
constant battle of who's gonna win? Who's gonna win?
I never was trying to win. There's no winning with you.
-Well, you were trying. -No, I wasn't.
So let's be honest. You were trying to win.
Win what?
Michelle, you said to people that we know,
"No matter what I do, everyone loves Jesse."
So what were you trying to do?
You have this charm, and you can turn it on to people,
and so people think you're funny, and people like you.
-That's all I'm saying. -Okay, but what were you trying
to do to get people to not love me?
I don't care if people love you or people hate you.
I know the real you.
Okay, well, that was the comment that you made,
so I just wanted to get some--
And you've made a lot of other comments.
JESSE: I have.
Um, well, a lot happened this season on "The Valley."
It was full of high highs and dramatic lows.
There was divorce, dysfunction, but also a surprise engagement
and two new babies on the way.
Through everything, this group faced it all together.
And I want to start by talking about the two new additions
to the family that are gonna be here soon.
-Mm! -Kristen, we followed along
with your struggles in your fertility journey.
Tell me about the experience of being pregnant
now that you're about to have your first baby.
Well, now that I'm near the end,
I'm like, it's gonna be so strange to not be pregnant.
I feel like I've been pregnant forever.
But watching back the episodes,
it was really difficult, like, seeing how distraught we were.
-Yeah. -And then I just feel so lucky.
How soon after the show wrapped
did you find out that you were pregnant?
Two weeks later?
-That sounds about right, yeah. -Yeah.
Yeah, about two weeks later.
That's great. Luke, how have Kristen's moods been?
-[laughter] -Better now.
-JASMINE: Right? -First trimester wasn't fun.
-Second trimester was-- -Absolute hell.
Was pretty okay. And now she's just in a lot of pain.
-And, uh... -We had, like, a good 10 weeks.
-Yeah. -Like, 20 to 30 weeks,
I was just like, life is great. Baby's kicking. Yes.
So in the end, what was it that--
that you think helped you get pregnant?
The hormones, for sure, and then the decision to do IUI came,
really, at the last minute.
It was just, like, an extra 10% chance that would help us.
So we decided, let's--why not?
You have a wedding to plan as well.
-Where are we with that? -Yeah. [laughs] Nowhere near...
BRITTANY: She doesn't ever talk about it, honestly.
-She hates stuff like that. -[laughter]
-Not till after the baby. -Yeah.
Well, we want to enjoy being engaged, too.
-Yeah. -BRITTANY: Yeah.
Because we haven't gotten to do that.
Right. Janet, you and Kristen have obviously had
your ups and downs. How's she gonna do as a mom?
I think she's gonna be a great mom.
She's the best dog mom in the world.
And that, I think, is the first big test,
you know, of taking care of something and loving something.
And I think she's gonna do a great job.
Thank you.
Well, there must have been something in the water
in the Valley that week,
because just as Kristen and Luke were conceiving,
their fertile friends, Danny and Nia
were getting pregnant with baby number four.
-What?! -Fertile friends.
Uh, Nia, this is your third pregnancy.
-You're pregnant? -[laughter]
How has the third time been for you?
It's been great.
Um, my second pregnancy had so many complications
and so many scares that this, in comparison,
is just very peaceful.
And I'm grateful 'cause I get to enjoy it.
And it's the last one instead of having
all the ups and downs like I did before.
Danny, we heard you complain a lot
about how little sleep you were getting with the three kids.
-Yes. -Why do this to yourself?
-[laughter] -I didn't.
-Why put yourself through it? -I didn't. She leg-locked me.
-[laughter] -That's a joke, by the way.
She's a fourth degree black belt, so...
-This is true. -Is a vasectomy in your future?
-Should be. -Or are you gonna go
for five under five? -I was just gonna say,
if anybody else wants--
guys, wanna be a part of a vasectomy, uh...
So Jax definitely needs one.
Danny and I are gonna hold hands.
You wouldn't even do Scrotox with me.
I'm not gonna do a vasectomy with you.
We're gonna hold hands and go in together.
Why? do you wanna get a vasectomy?
-Oh, yeah, yeah. -You do. Really?
-That's a good idea. -He's gonna have 20 baby mamas
if he doesn't. -Ooh.
-Do you use birth control? -Do I use birth control?
-No. -Yeah, are condoms
a thing for you? -Yeah. Um...
-Condoms are birth control. -Condoms, they're called.
-Oh, uh, I'm not really-- -Like, what's a condom?
-You have to explain it to him. -He's disgusting.
I will not touch that dirty dick with a 10-inch pole.
Okay.
-Whoo. -That's not what you said
four months ago when we were out at the aquarium and you're like,
"You think we should hook up one more time?"
You said that at Hooters four months ago.
-Doubtful. -So you were drunk, too.
But now that I know everything that you've done and everything
you've got going on down there,
there's no possible way I would touch you.
You literally hooked up with a guy who was
hooking up with porn stars. -You do that, too!
You're with OnlyFans models and porn stars yourself.
The condoms all over the floor and the...
-Hey, at least I use 'em. -JANET: Amen. Safe sex.
Okay.
***
ANDY: Coming up on "The Valley" Reunion...
JESSE: My life is a mess. I spoke to my attorney.
Wait, aren't you representing yourself?
Yeah.
***
-Even Jax is saying it. -What?
-Janet looks great. -Yeah, you do.
-Thanks. -You look amazing.
If you count the baby, I lost 70 pounds.
That's amazing. I put on 35, so... [laughs]
STAGE MANAGER: [filtered voice] Look at Andy.
Returning five, four, three to the jib, two...
Welcome back to "The Valley" Season 2 Reunion.
Kristen, have you and Nia bonded a lot during your pregnancies?
Oh, yes. I-I don't know what I would do without her.
-Wow. -Like, from just, like,
the fertility journey alone, which everyone
got to see on the show... -Yeah.
...through the whole pregnancy, and already she's telling me--
helping me with, like, postpartum, giving birth.
Like, it's the best thing I could ask for.
Nia, you were really open about your struggles
with postpartum depression. -Mm-hmm.
Are you nervous that that could be a reality for you again?
No, I'm like, where's the wood to knock on?
Right.
Um, I didn't have any postpartum depression
with my first pregnancy. I think it was just twins
and, like, all the extra hormones
maybe with the second.
So I'm hoping I don't have to deal with it again.
Uh, but I know that's also something that's chemical
and can be out of your control, but I know I have
a great support system and great friends,
so either way, we'll be okay. -Regarding your body image,
it seems like you put so much pressure on yourself.
-Mm-hmm. -And it kind of breaks my heart.
My number one focus would be my breasts.
They used to be beautiful and perky and great,
and now I feel like they're down to my belly button.
Um, and then, like, my next concern is kind of my stomach.
Whew. Um...I mean, just being completely honest,
like, we live in L.A.
I've been in the entertainment industry for quite some time,
so I do still feel that pressure.
Um, and I think it's okay to want to feel good in your skin,
um, and also give yourself grace.
Like, I really do try to find the balance.
Nia, are you planning a mommy makeover?
-I can't wait. Oh, my gosh. -[laughter]
-Do it. -I'll do it with you.
-Thank you. -I'll do it with you.
Okay, great. We can all go together.
-I'll do it with you. -[laughter]
-What do you wanna have done? -I mean, for me,
after breastfeeding four babies,
I can't wait to just feel good, you know?
Uh, Kristen and Nia, your due dates are a week apart.
One week apart.
You guys could give birth on the same day.
-Yes. -I'm down for that.
And Zack wants us to have adjoining rooms
so he can get content... -On both.
-...and, like, go... -And just visit both of us.
-And just go back and forth. -[laughter]
Are you delivering in the same hospital?
-Yes. -Yes.
-Yeah. Yeah. -You are. Wow.
Michelle, seeing Kristen and Nia,
is it giving you baby fever?
Sometimes yes, sometimes no.
[laughter]
I remember not sleeping and your back hurting.
-I don't miss that. -Have you and Aaron talked
about having children or getting married?
He's always mentioned it, and he's amazing with Isabella.
He wants multiple. I said that wasn't gonna happen.
-I said that from the beginning. -[laughter]
-But, yeah, I'm open to it. -You think you'll get engaged?
Um, there's no rush, but that's the goal.
Well, this season, we saw not one
but two married couples
reach their breaking point and file for divorce.
I wanna start with Jesse and Michelle.
Michelle, last season, we saw your relationship
on the rocks and Jesse fighting to keep the marriage together.
What was the tipping point that made you leave?
It was not one specific thing. It was a lot of things.
It was just, I was so tired of every day
being the same thing with you.
You were always diminishing me and putting me down.
And there was so many other things.
That's just the bare minimum.
And I was just like, why do I want to be married
to somebody that talks to me and treats me like this
every single day?
And finally we had an anniversary,
and I said, "Am I gonna feel like this until the day I die?"
No, and so I was scared, but I asked him for a divorce.
Jesse, we saw you and Michelle struggling, uh,
to co-parent this season. Has it gotten any better?
I think we're pretty good when it comes
to decisions for Isabella.
I know that she weaponizes Isabella.
-No, I don't. -I weaponize Isabella.
-Yeah, you do. -I really don't.
-Yeah, you do. -No, I don't.
Read comments online. You weaponize your daughter.
-No, I do not. -Well, excuse me.
-It's not up to the commenters. -No, I know. I get it.
-And I do the same. -I love my daughter,
and I have never used our daughter.
Explain what you said to my mom.
I said, "If you're not gonna allow Isabella
to see my mom, who's going to die,
she will not be flying to Boston for Christmas
and spending a week in Boston."
-"Ever again"... -Yeah.
-...is how you ended it. -Exactly.
NIA: I would feel the same way, though.
I think she should have said that.
If my mom was dying, I would feel the same way.
-That was messed up. -Okay, well...
Find a way to have empathy for her for that.
I know. I understand, and she knows the truth of that story.
Yeah, and then-- then what happened? It worked.
And that's how I have to talk to you.
I have to treat you that way.
But you still weaponized Isabella by using her to--
-Her mother was dying. -I understand. The truth is,
I never said she couldn't see her dying mother.
She planned a trip to go to Italy
with her boyfriend for two weeks.
-Yeah. But even before that. -She wanted her sister
to take the baby for a week and then me take her for a week.
I hired a behavioral therapist to teach us...
We hired a behavioral therapist. We. We.
...teach us how to talk about mortality with a 4-year-old.
-Okay. -Yes.
And they told you that she needed to see my mom.
-A hundred percent. -They needed--and they had
to tell you that you needed to give me grace, and you had
to do all these things, which you didn't do.
Okay.
Michelle, what's the status of the divorce?
Um... [sighs] so we have a custody agreement.
We've been trying to work on a settlement.
I have a lawyer. He does not. It has been a--
You don't have a lawyer?
No, it's been very expensive for me...
Don't you need a lawyer?
-...the last six months. -ANDY: No?
He represents himself, so he thinks he knows the law.
I've watched "Suits" three times.
-[laughs] I was about to say. -Oh, my God.
I'm currently watching it right now.
I was about to say, you watch "Suits"?
You think Jesse could pass the bar?
It should be a relatively clean divorce.
There's no assets, so what's the issue?
He got mad that I spent any money during marriage,
so he wanted me to pay him back money I spent during marriage.
No, that's not how it went.
That's actually exactly how it went,
and there's a million other things
that we don't have to talk about, But he just wanted me--
Oh, we're gonna talk about 'em. That's what the reunion is for.
Okay. You wanted me to pay you a lot of money to divorce you.
That's ultimately what it came down to.
JESSE: Okay.
Um, is there something about the wedding that is--
that is at issue?
So we had--we had had the conversation.
She said, "Jesse was making more money than me at the time."
-Right-- -He wants Michelle
to pay him back half the money for the wedding.
-Yes. -Yeah.
-You do? -Can we just say that?
-Who paid for the wedding? -Yep. I know.
We're like, let's say what it was.
-I paid for the wedding. -You paid for the wedding?
-JESSE: Yeah. -I-I-I paid about...40 per--
$10,000.
-No, I didn't. -How much was the wedding?
-I sent the spreadsheet to you. -How much was the wedding?
-By the way, our wedding was-- -150.
-$150,000? -Yeah.
-Yeah, 55 people. -And you paid for it.
-Oh, my God. -And at the time, were you
happy to pay for it? -We discussed splitting it.
-No, we didn't. -Yeah, we did.
-No, we didn't. -Now he wants her
to pay him back. -Now he wants her
to pay him back. -Now you want her to pay
for the wedding? I mean... -So here's the thing.
It's like giving back presents. You can't do that.
-Yeah. -Our entire divorce, sadly,
and this is what I was gonna say, has become tit for tat.
-Sounds like it. -And, you know, she wants me
to pay her back for a Napa trip, so I want her to pay back--
I don't want you to pay anything back.
-I actually--can I just-- -Why don't you guys
just call it even? -Can I just say--
-Let him have it. -She's been asking that.
Let me just--let me just finish. Let me finish.
Well, at least say the truth when you're speaking.
-So, Andy. -Yes.
So what I was working on this week when I got her discovery,
I was like, I am-- -My discovery?
-This war of attrition... -ANDY: Yes.
...is exhausting. Like, I'm done.
-Okay. -So I reached out
to her attorney about how to move forward,
because I want her to move forward with Aaron.
My life is a mess.
I wanna start putting out fires where I can.
-Okay. -I spoke to my attorney.
-You don't have an attorney. -You know, there's, uh...
Wait, aren't you representing yourself?
-Yeah. Yeah. -So you spoke to yourself?
-So you spoke to yourself? -No, I have a--
-[laughter] -I have a team of consultants
that I work with. -Is that Jason?
I'm not on the team. I'm not on the team.
[laughter]
All right, we're gonna be right back.
Coming up next...
Jax, do you think it's gonna be hard for you
when Brittany starts dating a man,
and she introduces him to Cruz?
[sighs]
***
I forgot, Jax, you were down there. You're so quiet.
-Wow. Can I run to the restroom? -I'm scared. That's why.
-[Janet laughs] -[chuckles]
STAGE MANAGER: [filtered voice] Everybody looking at Andy.
We are back. Jesse, how are things
with your girlfriend in Orange County?
Uh, they're good.
Do you two watch "Baywatch" together?
[laughter]
Uh, we do not, no.
[laughter]
Michelle, how is your relationship
with Jesse's girlfriend?
Do you know her? Do you intersect with her at all?
I don't have any sort of relationship with her,
nor do I want to.
Do you hear from her ever?
I...
Especially after last summer, I asked to stop contacting me.
I do not want any communication.
My girlfriend made the decision, probably about--
I don't know, maybe a month after we started dating,
to reach out to Michelle, to set boundaries, mother to mother.
I mean, a month into the relationship--
that seems pretty new.
You've been dating her for a month?
Yeah, because we were-- we were together for a month,
and she was spending a lot of time with Isabella,
so she wanted to know mother to mother.
And what I told Jesse, and our agreement was,
these are him and I conversations.
Aaron doesn't need to be involved.
She doesn't need to be involved. The decisions are between us.
You guys had agreed to not have anyone around your child?
-Yeah. -And Michelle did not have
Aaron around Isabella ever,
and you had Isabella around her and never told Michelle
and then tried to get mad at Michelle because
she finally wanted to have Aaron around,
and you said no because he was a man.
-JESSE: So-- -But yet you had her
stay the night with Isabella. -Braid her hair.
-Yeah. -And Isabella tells her
that she's braiding her hair the next day.
So you were the one that messed up first.
Well, I'm glad that you guys have the one side
of the narrative. -But is that not what happened?
-So the story is... -[laughter]
-Oh, my gosh! -Jesse's story. Jesse's story.
If you want-- If you want the other side--
-I just had to say it quick. -You want the other side?
Well, I just--I know for a fact what happened.
Michelle came up to me-- Michelle came up to me and said,
"I will never put my daughter in an unsafe position.
I can introduce her to whoever I want."
And I said, okay, that's what I can do also.
And I will let you know when the time is right,
and--and you can even meet him if you want because
you were trying to tell me, "You're never gonna introduce
a man to our daughter." -I saw the messages myself.
Yeah, what I said is I felt it was different introducing
a little girl to a girl who's also a mother,
as opposed to a little girl meeting a 35-year-old guy...
-That's control, Jesse. -The rules are not the same.
-Exactly. -...who had a roommate when
Michelle started dating him. -That's the frustration.
-The rules are not the same. -And Michelle had been
dating Aaron much longer.
I just thought it was different, and it--
It might be. But you know what? It was...
I mean, my little girl meets...guys.
You just wanted to be in a relationship for a while
before you introduce another-- another partner.
What did you make of the rumors
that your girlfriend was saying negative things about you?
I don't believe it. You know what I mean?
She kind of holds my feet to the fire, and I love that.
Can I just tell you one thing?
We were at, uh, Melissa's birthday party...
-Yeah. -...at TomTom.
I don't think she, like, likes you.
-Okay. -Like--
Why do you not think that Jesse's girlfriend likes him?
She just talks horribly about him.
Actually felt bad for you because the way
she spoke about you was like she did not like him at all.
Like, what was she-- what was she, like--
-Very dismissive. -Yeah.
-"We're kind of together." -Does that concern you at all?
-No. -I mean, do you think she's--
BRITTANY: She says she doesn't sleep with him.
ANDY: Do you think she's making this up?
BRITTANY: You know I'm not.
I mean, it fits a perfect narrative for Michelle.
You know I'm not making that up. I promise you.
I felt-- I've actually felt bad.
Well, I honestly, I appreciate you feeling bad.
Yeah.
But don't worry about me. I'm fine.
Janet, you mentioned in Santa Barbara that she was
threatening legal stuff?
That's where it turned for me. She wanted to silence Michelle
from talking about the "Baywatch" thing
and a lot of other bullet points.
No, so it was a cease and desist letter, not a lawsuit.
She didn't sign a contract.
She didn't take money like Aaron did.
-Aaron didn't take a dollar. -Okay, but he certainly--
-Aaron didn't take-- -But he certainly--
certainly showed up quite a bit. -He didn't even--
-Well, he didn't do it for her. -Which is great.
If you're gonna date somebody on reality TV, it's important.
Nobody's holding a gun to her head to date you.
And Jason's advice was don't date somebody...
-Yeah. -...who agreed to share
their life on camera...
Oh, Scheana was very vocal about it.
...if she feels very private about it.
Scheana called my girlfriend and said, "No one will like you
as long as you're with Jesse." That's what she said.
Jesse, do you think Michelle is anxious to finalize her divorce
with you so she can get married to Aaron and start a new family?
If that's the next step, that's fine.
Jax, hearing all of this, do you think it's gonna be hard
for you when Brittany starts dating a man,
and she introduces him to Cruz? -[chuckles]
-Yeah. -Yes.
How are you gonna to deal with that?
I don't know. Um--
Andy, he starts a fight with me every single day
about who I talk to and who I'm around every day.
Why do you have any jurisdiction
about who she's talking to? -I don't. I don't.
It's just-- This is just my mentality.
I'm trying to work on it. I really am.
Just keep it to yourself. Don't say it to her.
-I know. -Yeah.
-I get triggered, and I just-- -Do you have a therapist?
-I do. -Do you go to that therapist?
-Yeah, every Monday. -Really?
Yeah. I've been to four different therapists,
and they don't work out.
This is the first one that's actually worked out.
There were many that you weren't just up to.
No, I was going to a lot of 'em.
I went from going to a community college,
working two jobs, and being a normal guy
to now I'm living this rock star lifestyle.
I can't be faithful. I'm ashamed about this.
This is like--it's like a sexual problem for me.
It is. It's like it's embarrassing.
-Like a sex addict? -Some people do drugs.
Some people drink alcohol.
This would be probably one of my things.
So repeat after me. "I have all this anger."
-I have all this anger. -"So I burst out."
So I burst out.
-"And I hurt people." -And I hurt people.
I'm on the right path, and I'm not talking about it.
I'm not like, "Well, I'm changed, and I'm this."
-I'm just doing it for myself. -Yeah.
I know he's done so much, and he has changed so much.
And I do trust him again, but there's still, like,
a little bit of me that doesn't trust him.
Actually, we--if you remember
through the years of "Vanderpump,"
I had, like, two or three that got in trouble.
-There was one. -Well, there was a Reiki healer.
-Yeah. -I mean, there was a--I mean...
You're 100% right. I was anti-therapy.
I'm like, I'm not gonna just dish out my personal stuff.
She's been telling me to get help for many, many years,
and I-I didn't listen at all.
Going to the rehab, which... [inhales deeply]
...was very eye-opening,
I wish I would have done it a long time ago.
Me, too.
I'm not saying it would have helped my marriage.
-Right. -But it would have helped me.
Have his Monday therapy sessions improved...
-She's aware that I go. -...anything for you, Brittany?
-No. -ANDY: No.
Jesse, I wanna talk about your budding bromance
with Kristen and Luke.
You reached out to Kristen with an apology
at the beginning of this summer. Why?
Kristen sent me the most gracious text message.
I was like, "Wow, that's very, very big of her
to take the first step."
And I started to just think about what my role played
in what happened last year.
Shut the fuck up! You walked into my house.
All I'm doing is repeating--
-Shut the fuck up! -Jesse, you shut the fuck up!
Sit your fucking ass down right now.
What the fuck did you just say to me?
-What are you saying to me? -Hey! What the...
-What do you say to me?! -Problem's with your wife!
I'll fucking get you!
Kristen, what had you seen in Jesse prior to the apology
that made you open to a friendship?
I mean, when he asked me to come over,
that was just sheer curiosity.
Like, I had to know and I had to go,
and especially because it was just me,
and Luke was kind of like,
"Mm, do you want me to go for support?"
And I said, like, "I can handle it."
-You want me to call security? -Yeah.
-[laughter] -Within our conversation,
something else that he said to me that really, I think,
hit me the hardest was that he didn't realize how triggering
certain things can be for people.
Example, like him putting his fists on the table.
I think this is all on you, Kristen.
And I--And I wish you didn't bring it to my front door
-Or from Zack. -You know what the problem is?
But yes.
Do you know what the problem is?
She should not have brought it up.
Everybody shut the fuck up! Michelle's gonna talk.
To him, didn't mean very much, but he was like,
"I didn't realize with my past with exes,
that could be something that totally sets me off
for, like, almost no reason." -Mm-hmm.
I was like, "Wow, that's so genuine.
You really are listening." And there was no "I'm sorry, but..."
So it made it really easy to give him a chance.
Michelle, what did you make of Jesse's apology to Kristen
and their friendship now?
I thought it was very ironic and interesting.
I know what you thought of her before.
I know what you used to say.
And what I thought of him before.
Yeah. He knew that talking to you and befriending you
would make me upset and turn the whole situation.
There's a plan behind that.
But you know he doesn't speak ill about you in front of me.
And if he were to, it wouldn't fly with me.
Yeah, I believe that he manipulates you.
Not easily manipulated, though.
Like, I consciously make a choice.
[chuckles]
Michelle, you told Jesse that he loves to cry
so people think that you are a cold, insensitive person.
Yeah, well, I am naturally just, like, very guarded.
And it's very hard for me to cry. He can cry on demand.
We were both trying to win and one up each other,
and I think whatever power I have left, I...
[voice breaking] like, give it to you
to do whatever you want with it,
say whatever you want about me 'cause I'm just so tired.
It's--It's fucking overwhelming right now. [sniffles]
It's gonna be easier to connect with somebody
if you see a crying man being vulnerable.
I think the conversation was one of the most raw, vulnerable,
honest from both of you in that moment.
-That conversation was... -Yeah, and it went real south,
like, the same day. -It went south, yeah.
It did. Jesse, have you always been a big crier?
I've seen "Rudy" 40 times, and I cry every single time
they carry him off the field at the end,
so, yeah, it's just how I've always been.
You think you could eke out some tears tonight?
Uh... [chuckles] There'll be some tears tonight.
-I can guarantee it. -But will they be real?
Shady.
-They're always real. -I will say it was interesting
seeing a conversation between you guys.
You started crying, and then she said, like, "Come on."
And you--it--they dried up rather quickly.
-What conversation was that? -The scheduling.
I don't wanna be away for two holidays from Isabella.
I just don't.
You love to cry.
I might get aggravated, and I might get, like, resentful,
but you're so angry.
I was like, oh, suddenly the tears are gone.
JESSE: Those tears were like the first holidays
since we separated that we wouldn't be together.
At the time we were filming, you guys had only been
separated for less than a year at that point, right?
-Yeah. -I think it's pretty reasonable
that unless you're saying or people are saying
Jesse's a total sociopath, that, like, he would have tears.
Like, it's an emotional situation for anybody, right?
Yeah, exactly. I agree.
***
ANDY: Coming up...
Michelle, you told the girls
that Jesse had spent all your money and is broke.
Yeah.
I mean, I seem to be living fine right now.
Who's paying your rent?
***
We are back with the gang from "The Valley."
Nia, I heard about your new house in Santa Clarita.
-Oh, he got me. -He won.
Yeah.
How was Danny able to convince you?
You know, it's the house and the space.
Anytime I think about, like, oh, we're in Santa Clarita,
I kinda get down, but we have five bedrooms.
[laughs]
Danny keeps saying it's 20 minutes away.
-How far is it from-- -It is not 20 minutes.
-No, it's not. -You're lying to yourself.
When we went to Brittany's house for...
-BRITTANY: Cruz's birthday. -Cruz's birthday.
...from our house in Santa Clarita,
it took 18 minutes.
-Okay. -We're closer to the Valley.
That was a Saturday. On a Friday afternoon...
-18 minutes! -1 hour.
18 minutes!
Jasmine, did you sell them the house?
-No. -No.
I don't work that territory.
-You don't work. Oh, okay. -Just kidding.
-All right. -[laughs] I'm just kidding.
As multiple marriages were coming apart at the seams,
a thread known as "the boys chat"
was going strong,
fueled by drama, scandal, and rumors about Michelle.
Jax, for all of us who are not lucky enough
to be on the boys chat, pull back the curtain for us.
What--What kinds of topics are y'all discussing?
-JAX: Well, we started-- -Dirty.
We started at Schwartz's wedding.
-ANDY: Okay. -That's where it started.
Oh, you're gonna make me cry.
-Let's try not to cry just yet. -I know.
***
-You look good. -Look good, too, man.
-You're doing okay. -Cutie.
[chuckles]
-[whispers] We did it. -LISA: Oh, puppies.
It kind of just started out as, like,
you know, uh, all the guys talking to each other.
'Cause we were all, like, living in little--I think it was,
like, little houses on the property at the time.
So we were just all communicating...
-ANDY: Okay. -Sending pictures
of, like, stripper vaginas to each other.
-Not in the beginning. -And degrading women 24/7.
Yeah.
Okay, who on this stage is still in the boys chat?
Well, I was on it at one point, and I literally got out
because of exactly what she's saying.
-One vagina, Zack's out. -[laughter]
Okay, so really, it's only Jesse and you
that are in the boys chat here? -Correct.
Danny, you're not in it anymore?
-Uh, no, he kicked me out. -You got kicked out?
-Jax kicked me out after he-- -Lucky you.
Jesse was trying to say
that Michelle was hooking up with a billionaire for money.
***
Did he actually say that?
This was...said.
It's okay. Listen, we know it's not true, Michelle.
This is gonna come back to me really bad.
It is. But it's too late. It was said,
and you know you gotta own it. -We know it's not true.
-We know it's not true. Girl. -And you gotta--you said it.
Brittany, uh, when you and Jax were together,
what kinds of things did you see in the boys chat?
Oh, he showed me everything.
He would show me Jesse's messages.
He would talk about how horrible Jesse was and all this and that.
Like, he did not like Jesse, I don't think, like, at all.
He was showing, like, all these naked girls and everything.
And there was just a lot of dirty, nasty things in there.
It was--It's locker room talk.
-Okay? -Yeah.
Danny, you broke the first rule of the boys chat.
Don't speak about the boys chat.
[laughs]
Um, why did you tell Luke that Jesse said Michelle
was sleeping with a billionaire for $1,500 a night?
[child babbles]
Hand to God, I...
obviously had my mic on.
We were talking and having a conversation
about Jesse and Michelle.
-It was wrapped. -You thought it was wrapped.
I didn't know that there was a camera behind me.
That's why, literally, I'm whispering
after we were talking about Jesse.
Jesse, why did you say that about Michelle
in the first place?
-Um... -Did you really believe it?
No, I never believed it. And I just blurted it out.
And I regret--the second I sent it, I regretted it.
Michelle, you told the girls that Jesse
had spent all your money and is broke.
Yeah.
I mean, I seem to be living fine right now, and she--
-Who's paying your rent? -And she is--
Uh, I am paying my rent and have been since you moved out.
Who has been lending you money to pay your rent?
You talked at the Zen party
about being overwhelmed financially.
-Yeah. -It's okay to admit it.
-Do you still feel that way? -It's, um...
It's okay to admit it.
It's double the expenses with half the income.
And we sat down in the living room,
talked about her moving out, and we had actually talked
about the two of us finding a new place.
What happened was you said I had to leave the house,
and you were never gonna leave 'cause it was "your house,"
even though we both rent the house.
I never once said you had to leave.
And you said, "I'm not leaving, over my dead body,
and you sleep downstairs."
So I started sleeping downstairs while you were
sleeping in the master bedroom. -Yeah.
Then you said, "We have a lease agreement,
so even if you move out, you have to pay me rent."
So what did I do? I tried to live there
so I didn't have to pay two rents.
It was unbearable. So finally I found a place.
I bought new furniture, and I was paying two rents.
-That's what happened. -Okay.
Jesse, Michelle said that
through the course of your marriage,
the more money you got, the douchier you got.
-[chuckles] -Did money make you douchey?
-Um, I don't-- -Just say yes.
To be honest, I think I was pretty douchey
when I was a caddy at the golf course
making $150 a loop. -He used to have a tongue ring,
so I think he's always been a douche.
-You had a tongue ring? -I had a tongue ring, yeah.
-I had a tongue ring, too. -When you married him...
-Oh, you did wear it? -Yes.
-Oh, no. -I had one, too.
-Now I can't make fun of Jesse. -[laughter]
-It was popular then. -DANNY: Not for dudes.
-No. -[laughter]
We need to take a break. We'll be right back.
I was, like, 18 or 19.
ANDY: Coming up next...
When you're in a toxic relationship for so long,
you just don't have any interest anymore.
We barely had sex for, like, the past three years
of our relationship. -That's correct.
So why would I be like, "Yeah, he's great in bed!"?
***
* Should get your number *
* I'll show you everything that you've been missing *
No.
See, they charge.
I don't make anything. I--
You told everyone when we gave birth.
Oh, I'm talking about the show.
I'm talking about the show. I don't do that.
-Why would I do that? -I don't know.
You guys--You guys are the ones that go and live on Reddit
and leak shit. I don't leak shit.
I've been doing this for 10 years.
JANET: I don't leak things. I read.
STAGE MANAGER: So we're gonna start with a bump in.
We'll have everybody look towards Andy.
We are back with "The Valley" Reunion,
and this season opened
with the shock of Jax checking himself
into a mental health treatment facility.
So I wanna start at the beginning
and talk about what led up to that.
So, Brittany, just days before filming started this season,
you and Jax were separated
but talking about getting back together.
Then you had a fight at your house
that changed everything.
I wanna discuss what set Jax off.
The text messages between you and Julian...
-Mm-hmm. -Jax's friend and Lala's ex.
-Mm-hmm. -Right?
JAX: Julian and I were friends.
We were hanging out all the time.
Um, so how soon after your separation from Jax
did you start seeing Julian?
Probably like a month. Pretty quick.
-And, Jax, what were the rules? -Quicker than that.
No, it wasn't.
What were the rules that you and Brittany established
about dating inside your friend group?
I mean, honestly, I don't think we really
set a rule on the friend thing. -Mnh-mnh.
You just automatically assume.
I think it was a little sooner than a month.
I don't know, but I just think...
[sighs heavily] it was just hurtful.
And I went against what I said, too.
I had somebody at my house, which is not right.
-BRITTANY: Multiple people. -I'm not trying to start
a war here. It was just, that's what
was hurtful to me, and this is what made me spiral.
He was extremely aggressive.
-Yes. That's true. -He threw the coffee table.
It landed on my knee. It turned black immediately.
He threw both barstools.
He threw my Stanley cup and broke it.
He threw my phone and broke it. He threw my laptop and broke it.
He threw me into the rose bushes. He--
I didn't throw you in the rose bushes.
Yes, you did. It's on my Ring camera doorbell.
I'd never throw you in the rose bushes.
-KRISTEN: Yeah. -Yes, you did.
-No, I didn't. -Yes, you did.
Everybody, my close friends up here have seen the videos.
-How long did you-- -Sorry, it makes me mad.
-No, you're good. -How long did you date Julian?
-We never, like, dated. -ANDY: Okay. Hanging out.
We were just, like, hooking up a couple times a week.
And I will--another thing I need to say about that. Whatever.
Maybe it was weird that I hooked up with somebody
that was around the friend group,
but my confidence was at an all-time low.
This man degraded me, put me down,
body-shamed me constantly.
Okay? Julian gave me attention that I needed in that moment.
He made me feel sexy. He made me feel beautiful.
He gave me some confidence back.
While he was dating five other girls at the same time.
It doesn't matter! He was what I needed because
you made me literally lose my sparkle.
I lost a lot of my personality being with you.
-Mm-hmm. -And everybody knows it.
I'm not arguing with you. Did you see me arguing with you?
You're going... [mockingly] "Lost your sparkle."
I just--enough with the "sparkle" word.
It's like, come on. I get it. I understand.
-You made her feel like shit. -Because that's how I--
-That's how I talk about myself. -I understand. I know, I know.
-I am very, very sorry. -I mean, I had your son,
and then you body-shamed me for stretch marks. Like, it didn't--
-I didn't body-shame you. -JASMINE: Yes, you did.
-I never said that. -BRITTANY: Jax, yes, you did.
-ZACK: Yes, you did. -I had your child.
-Your beautiful child. -Listen. Zip it down there.
All right? You're not part of this. Keep your mouth shut.
Jax, we've seen the text messages. We've seen it.
-ANDY: So, Jax-- -What are you talking about?
-We got to see it firsthand. -He won't stop denying it.
ZACK: So always comes for me. Always.
Literally called me a tree trunk because I had stretch marks.
-Maybe apologize? -I am very sorry about all this.
-It's just like, I-- -Are you very sorry about your--
I'm sorry about all of this, to be honest.
This is not how I wanted this. The last thing I wanted
for anybody to see was how this all got,
and I couldn't control it. -On "Watch What Happens Live,
Brittany didn't give your sexual prowess
the highest marks, Jax.
There was times when he was about a 7 or an 8,
but majority of the time, no stamina, no nothing.
-[audience exclaiming] -I'd say a 2 or 3.
[laughing] Why would she, though? It's her ex-husband.
So I didn't say, "Always." You said--
When you're in a toxic relationship for so long,
and there's just-- you--you just don't
have any interest anymore. -Drugs and alcohol.
-Like, and-- -He did not touch me for years
and did not make me feel good about myself.
He put me down. We barely had sex for, like,
the past three years of our relationship.
So why would I be like, "Yeah, he's great in bed!"?
-[laughter] -"Great in bed."
I pushed my wife away. I pushed her away.
And I did everything in my power to make her leave me.
And--And, you know, I caused so much pain
and--and so much drama over the years.
And the alcohol and the drugs was just the icing to the cake.
And I think--and I don't know if you'll agree with me,
but when it really started to get bad
was when I lost my job with "Vanderpump."
Because not only that happened, COVID happened.
My wife's pregnant, and I'm freaking out financially.
What am I gonna do? How am I gonna handle this?
-And Brittany was-- -You started turning on me
because I was the one making money instead of him.
Yeah, I was--Let me--Let me-- I was getting there.
Instead of being happy for me, he held it over my head
and held it against me. -I did, a hundred percent.
So I started-- She was making money still.
Shouldn't you have been happy that she was bringing money in?
Yes. Yes. But as I was, like, as a man, you just wanna
be able to support your family, and I was--
But we weren't in competition. We were a team.
I know. I was so angry about the fact that,
you know, I was parted ways with "Vanderpump"
that I was taking all that anger out on her.
And not only I had the baby on the way, we had COVID.
Like, where's the money gonna come from?
Me. [scoffs]
I'm not playing the victim at all.
But between the drugs and the alcohol and the anger,
I mean, Kristen used to tell me all the time,
like, "Jax, you have a fucking problem.
You're angry. The vein would pop out of your head."
-Yeah. -I couldn't...
I couldn't--I couldn't control it. I couldn't cont--
BRITTANY: The Julian incident was not an isolated incident.
He has acted that way many times to me,
and I am such a forgiving person.
And I loved him so much,
and I was trying to make our marriage work for years
that I brushed it off,
And I forgave him every time that he apologized
and promised me he would change, promised me he would get better.
I really believed him because I loved him so much.
[voice breaking] Like, you can never deny that
I tried everything I possibly could
to make this relationship work.
And you treated me worse than anybody else.
And I was the only one that loved you enough
to make you get help. It's really sad.
ANDY: What is the agreement you have about co-parenting?
I have full custody, and--but our divorce is not final yet.
But whenever the divorce is final,
I'm going to allow him to have him
every Wednesday and every other weekend.
And then, like, if I need to go get my nails done
or something like that, like, he can watch him.
Like, I'm not gonna ever not let him have his son as long as
he's passing his drug test. -And I agree.
Has Cruz been to your new condo?
Yes, she allows me to see him now.
It took some time, which I totally understand.
Another thing, too, is I really--
and I think Brittany can agree with me.
I don't want to uproot my son from his house.
-[laughs] Ooh. -So a lot of the times--
Yet I had to be the one to take our autistic son
and move him from Airbnb and Airbnb
because you would not move the house...
-No, I understand-- -..knowing that he
needs stability, knowing everything.
But your ego was so big that you made me and Cruz move out.
And then you didn't pay the mortgage for seven months.
Not the only the mortgage. I didn't pay my car note.
I didn't pay anything. I just let it all go.
And I was like, I'm done.
***
ANDY: Coming up after the break...
He went through my trash cans...
-Yeah. -...went through drawers,
counting condoms. Your personality is so sporadic.
So if it isn't the drugs, if it isn't alcohol,
if it isn't this, why are you still just as crazy as before?
***
JAX: Do you have a Kleenex?
There's a box of them somewhere.
STAGE MANAGER: All right, let's...
-Thank you. -Oh, I'm nervous.
I'm shaking and shaking. I get so angry and yell so much.
Yeah.
I wanna be able to, like, control.
-Don't give him your power. -Yeah.
STAGE MANAGER: Five, four, three to the jib, two...
We are back with "The Valley" Reunion.
After the explosive fight with Brittany,
Jax made the decision to seek help
at a mental health treatment facility.
Jax, what made you decide to seek help?
Many reasons. Um, my job was on the line.
-Um, my son. -Your job with the show?
Yeah.
I was such in a bad place, and I didn't wanna go.
I didn't think I needed help.
But thank God, because my job and my son--
those are the two most important things to me.
So, yeah, when you start taking those away,
it's like, Jesus, you need to--you need to go.
Jax, you actually went to rehab twice.
-Yes. -Yeah, I relapsed, yeah.
-When did you relapse? -I was two weeks after, maybe.
No, it was, like, it was, like, the week of.
-The week that he got out. -Okay.
But the thing was with the first time is he acted
like drugs and alcohol were not a problem.
Drugs and alcohol, I believe, are not the big problem.
I feel like you're masking hurt
whatever you're going through, fighting and walking.
Like, all the stuff that I was doing to Brittany,
and I was angry, and I just--
I would use drugs and alcohol to take it away for a couple hours.
You have been sober for how long?
156 days today.
-Congratulations. -Thank you.
-Sober from everything. -Everything.
-Except for weed, which is fine. -Except for weed.
I'm not even-- I don't care about that.
I can't stop smoking weed. It's not gonna happen.
-[laughter] -We're all okay with that.
And you believe that he is sober.
So he does pass his drug test. I've given him--
I've got, like, a pack of a hundred drug tests,
and I have given them to him sporadically.
-Twice. Twice. -Yeah. But you also--
I get a text every Monday from the guy.
So I made it a point to make sure
they call Brittany every Monday when I take my test
because I want her to know that I'm passing.
But who is the person that made that happen?
Nobody made it happen. It was the right thing to do.
-Are you on steroids? -I'm not on steroids.
Your attitude and your personality is so sporadic.
So if it isn't the drugs, if it isn't alcohol,
if it isn't this, why are you still just as crazy as before?
You're saying--You're saying his anger has not improved?
I don't think I'm just as crazy.
-No! -And so you--you worked
on your anger, apparently, in rehab.
-I'm trying to work on my anger. -Okay.
I'm still very trying to work on that.
But it sounds like what she's saying is it hasn't changed.
I think it's gotten a lot better.
-ANDY: You do. -Do you agree
it's gotten a lot better? -Some days it's okay,
and then the next day, it is absolute hell.
Like whenever it was Easter and he came over, that day was fine.
Very next day, he started a huge fight with me
for absolutely no reason.
Went through my trash cans, went through drawers,
my private drawers, everything,
trying to find if I had been hooking up with other guys.
-Counting condoms. -Yes.
He was extremely abusive, extremely aggressive.
Yes.
Why should she not be allowed to be seeing someone?
-She should. She should. -The disrespect is insane.
I would assume that you would agree
that if you were on steroids,
it would be detrimental to your anger issues.
-That's why I'm worried. -I'm not on anything.
-[scoffs] -Keep testing me,
and I want you to test me. It holds me accountable.
In my head, if I ever try to slip again,
I know that you're gonna test me anytime you want.
And I want you to test me anytime.
Not only for you, but for me, to hold me accountable.
BRITTANY: Yes.
[voice breaking] Because I don't wanna touch
drugs and alcohol again. It's fucked up my life.
Yeah.
And... [sniffles]
It's tough.
Like, it's fucking hard.
And I know it's hard for her, and I'm not--
She's the victim here, not me. Okay? But I...
I'm a human being, too, believe it or not.
I know some people think I'm not human. I'm the devil.
I get it. But I still have fucking feelings, too. I do.
This is the hardest fucking thing to do this
in front of God and everybody, and everyone's gonna see this.
You knew we were filming whenever you did these things.
Yeah, I knew that, but I'm not-- I'm not thinking about filming.
That's why our show is the real shit.
BRITTANY: Exactly.
Because I put everything out there.
[dramatic music swells]
ANDY: Next week it's Part 2 of "The Valley" Reunion.
If you're apologizing to me and you mean it,
you should be able to look me in the eye.
'Cause I'm embarrassed and ashamed of who I am.
-I didn't have a boyfriend. -You were seeing someone.
Cheating and cheaters-- that's my one thing.
That's really interesting,
because as soon as I asked for a divorce,
you started sleeping with a married woman.
-So which one is it? -Oh!
Your apology to me felt like shit.
I thought we were-- we were good.
You are a clown, dude. You're a total clown.
Are you kidding me? I'm a clown?
I am not kidding you. The fact that you won't
even admit that you have any issues...
-Jason. -Blame everybody.
Blame everybody for you being a douchebag.
[dramatic music playing]
Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.